<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Setting;
use App\Models\MailContent;
use App\Traits\ViewPathTrait;
use Illuminate\Support\Facades\File;
class EmailManagementController extends Controller
{
    use ViewPathTrait;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index($module)
    {
        // Define the directory path
        $directoryPath = resource_path('views/admin/email-management/' . $module);

        // Check if the directory exists, if not, create it
        if (!File::isDirectory($directoryPath)) {
            File::makeDirectory($directoryPath, 0755, true, true);
        }

        // Define the view file path
        $viewPath = $directoryPath . '/index.blade.php';

        // Check if the view file exists
        if (!File::exists($viewPath)) {
            // If the view doesn't exist, create it
            $this->createMasterIndexView($viewPath, $module);
        }
        if($module == 'mail-content'){
            $arr = MailContent::getMailContents();
        }else{
            $arr = Setting::getData($module);
        }
        // $arr = [];
        if($module == 'mail-settings'){
            $categories = [
                'primary','bcc','badge-mail', 'otp','electrical-contractor','furniture'
            ];
        }else{
            $categories = [];
        }
        $menuItems = json_decode(File::get(storage_path(auth()->user()->role . '_menu.json')), true);
        return view('admin.email-management.' . $module . '.index',compact('menuItems','arr','categories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $model = $request->input('model');
        if($model == 'mail-settings'){
            $data = Setting::insertData($model, $request);
        }else{
            $data = MailContent::insertData($model, $request);
        }
        return $data;
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = MailContent::all();
        $model = $request->input('model');
        if($model == 'mail-content'){
            $record = MailContent::find($request->input('id'));
            $mail_type = $request->input('mail_type');
            $user_type = $request->input('user_type');
            $mail_category = $request->input('mail_category');
            $subject = $request->input('subject');
            $content = $request->input('content');
            $exists = $data->contains(function ($item) use ($mail_type, $user_type, $mail_category) {
                return $item->mail_type == $mail_type && 
                       $item->user_type == $user_type && 
                       $item->mail_category == $mail_category;
            });
            if ($exists) {
                return back()->with('error', 'Record Already Exist.');    
            }else{
                $record->mail_type = $mail_type;
                $record->user_type = $user_type;
                $record->mail_category = $mail_category;
                $record->subject = $subject;
                $record->content = $content;
            }
            $record->save();
            return back()->with('success', 'Record Updated successfully.');    
        }
        $record = Setting::where('meta_key','mail-settings')->first();
        $arr = Setting::getData($request->input('model'));
        $arr['settings'][$request->input('id')];
        $arr['settings'][$request->input('id')]['type'] = $request->input('category');
        $arr['settings'][$request->input('id')]['value'] = $request->input('email');
        $record->meta_value = json_encode($arr);
        $record->save();
        return back()->with('success', 'Record Updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        if($request->input('model') == 'MailContent'){
            $id = $request->input('id');
            $record = MailContent::find($id);
            $record->delete();
            return back()->with('error', 'Record Deleted successfully.');
        }
        $record = Setting::where('meta_key','mail-settings')->first();
        $arr = Setting::getData($request->input('model'));
        if(count($arr['settings']) > 1){
            unset($arr['settings'][$request->input('id')]);
            $record->meta_value = json_encode($arr);
            $record->save();
        }else{
            $record->delete();
        }
        return back()->with('error', 'Record Deleted successfully.');
    }
}
